#
# spec file for package seq24
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           seq24
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtkmm-2.4) >= 2.4.0
Summary:        A Small, Real-Time MIDI Sequencer
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Midi
Version:        0.9.3
Release:        1.35
Source:         http://launchpad.net/seq24/trunk/%{version}/+download/%{name}-%{version}.tar.bz2
Source1:        %name.desktop
Source2:        seq24.png
Url:            https://launchpad.net/seq24
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Seq24 is a real-time midi sequencer. It was created to provide a very
simple interface for editing and playing MIDI 'loops.'

%prep
%setup -q

%if "%{version}" == "0.9.3"
# Bug in 0.9.3 and 0.9.3 prereleases
# class "mutex" in src/* clashes with "std::mutex" due
# to "using namespace std;". Rename mutex to seq24_mutex.
sed -i \
  -e 's,mutex::,seq24_mutex::,' \
  -e 's,\([ cs]\) mutex,\1 seq24_mutex,' \
  -e 's,::mutex,::seq24_mutex,' \
   src/*.h src/*.cpp
%endif

%build
%configure
make %{?jobs:-j %jobs}

%install
%makeinstall
%suse_update_desktop_file -i %name AudioVideo Sequencer
mkdir -p $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp %{SOURCE2} $RPM_BUILD_ROOT%{_datadir}/pixmaps

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README RTC SEQ24
%doc seq24usr.example
%doc %{_mandir}/man?/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png

%changelog
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 0.9.3:
  + Fixed Bugs:
  * Fix LASH support (crash on 64 Bit systems).
  * Fix broken JACK transport with newer jackd version.
  * Fix clock tick drift.
  * Fix jack session commandline (obsolete --file option
    removed).
  + New Features: Non recursive make.
  + General Changes:
  * Some code cleanups.
  * C++11 compatible compiler required.
- Use sed to workaround a bug in 0.9.3 release.
- Replace gtkmm2-devel for pkgconfig(gtkmm-2.4) BuildRequires,
  align with what configure looks for.
* Mon Dec 19 2011 coolo@suse.de
- update to 0.9.2
  * Fixed error if path for last used directory is not properly set.
  * Fix tooltip usage for older GTK versions (GTK_MINOR_VERSION < 12)
  * Fix sched_param memory leaks
  * Fix doubled key event for screen set name line
  New Features
  * Add support for jack session, patch provided by Torben Hohn
  * Add interrupt handler for SIGUSR1 to enable LADISH level 1 support
  * Add interrupt handler for SIGINT to ask for unsaved file changes
  * Remove "-f" command line option to be replaced by a simple <filename>
    argument (see "seq24 --help" for more information)
  General Changes
  * Add mnemonics for bottom line widgets in main window and label for
    screen set name edit line
  * Add missing command line parameters to help message, display short
    options as well
  * Add command line option for program version
  * Add missing command line parameters to man page
  * Remove complaints about file read error if configuration files do not
    exist
  * Cleanup configure.in: remove unused variables, harmonize option
    enabling/disabling
  * Some code cleanups
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Apr 20 2010 davejplater@gmail.com
- Update to latest bzr checkout 2010-02-21
- Summary of changes:-
  * Merged constructor initializer lists.
  * Merge removal of useless nullity tests
  * Cleanup : removed some unused variables, reduced unecessary
    big scope of some other variables
  * Wrapped reading of single bytes, and removed the
    push_front/reverse list browsing insanity.
  * Use STL in midifile instead of news/deletes
  * Plyphonic Step Edit
  * Monophonic Step Edit on Sequence
  * Fixed adding notes on the begining when midi record is on
    and not playing sequence
  * src/perform.cpp: Fixed jack_position_t->bar calculation which
    always where 0 or negative while using Hydrogen 0.9.4 at the
    same time.
  * See /usr/share/doc/packages/seq24/ChangeLog for more changes.
* Tue Apr 20 2010 pth@novell.com
- Determine return type of Gtk::Dialog::get_action_area in
  configure and use result in mainwnd.cpp
- Fix Compiler warning.
* Mon May 11 2009 tiwai@suse.de
- updated to version 0.9.0:
  * Several bug fixs, contains adaptations to library API changes,
    string buffer overruns, 64Bit incompatibility and memory leaks
    for MIDI file format errors.
  * See ChangeLog for more details
* Wed Apr 16 2008 tiwai@suse.de
- fix build with recent sigc++-2.
* Wed Nov 28 2007 tiwai@suse.de
- fix build with old suse version
* Wed Oct 31 2007 ro@suse.de
- include assert.h for alsa source
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 0.8.7:
  * Undo support (Ctrl-Z)
  * Ctrl + Select Adds to Selection
  * Window Raise on Edit
  * Clipboard shared among editors
  * Items remain selected after edit
  * Can now 'paint' notes / events in editor
  * Paste buffer doesn't clear
  * Added new rc file for custom named ports and CC codes
  * Keypress Start (space) and Stop (escape)
  * Shift + Middle Mouse will now stretch events over range
* Thu May 18 2006 tiwai@suse.de
- updated to version 0.8.6:
  * use gtkmm 2.4 or later
  * new song editor
  * loop sync with jack transport
  * midi clock option, split loops, manual midi ports
  * menug bug and cpu hog fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug  4 2005 tiwai@suse.de
- updated to version 0.6.3.
* Fri Feb 11 2005 ro@suse.de
- change to libsigc++12 in neededforbuild
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.6.0.  Linked with gtk2.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.5.2.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 0.4.4.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Mon Aug 11 2003 tiwai@suse.de
- updated to version 0.4.3.
* Fri Jul 18 2003 tiwai@suse.de
- initial version: 0.4.2.
